#
# spec file for package python-py2pack
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-py2pack
Version:        0.6.3
Release:        1.1
Url:            http://github.com/saschpe/py2pack
Summary:        Generate distribution packages from Python packages on PyPI
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         https://pypi.io/packages/source/p/py2pack/py2pack-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-Jinja2
BuildRequires:  python-argparse
BuildRequires:  python-cssselect
BuildRequires:  python-devel
BuildRequires:  python-lxml
BuildRequires:  python-requests
BuildRequires:  python-setuptools
BuildRequires:  python-six
Requires:       python-Jinja2
Requires:       python-argparse
Requires:       python-cssselect
Requires:       python-lxml
Requires:       python-requests
Requires:       python-six
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This script allows to generate RPM spec or DEB dsc files from Python modules.
It allows to list Python modules or search for them on the Python Package Index
(PyPI). Conveniently, it can fetch tarballs and changelogs making it an
universal tool to package Python modules.

%prep
%setup -q -n py2pack-%{version}
#sed -i "1d" py2pack/py2pack.py # Fix non-executable script

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# The setup script installs stuff into '/usr/local', move stuff around accordingly
install -d %{buildroot}%{_mandir}/man1
install -d %{buildroot}%{_docdir}/%{name}

mv %{buildroot}/usr/share/doc/py2pack/* %{buildroot}%{_docdir}/%{name}
mv %{buildroot}/usr/man/man1/py2pack.1 %{buildroot}%{_mandir}/man1/py2pack-%{py_ver}.1
ln -s -f %{_sysconfdir}/alternatives/py2pack.1.gz %{buildroot}%{_mandir}/man1/py2pack.1.gz

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
mv %{buildroot}%{_bindir}/py2pack %{buildroot}%{_bindir}/py2pack-%{py_ver}
ln -s -f %{_sysconfdir}/alternatives/py2pack %{buildroot}%{_bindir}/py2pack

# create dummy targets
touch %{buildroot}%{_sysconfdir}/alternatives/py2pack
touch %{buildroot}%{_sysconfdir}/alternatives/py2pack.1.gz

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/py2pack py2pack %{_bindir}/py2pack-%{py_ver} 30 \
   --slave %{_mandir}/man1/py2pack.1.gz py2pack.1.gz %{_mandir}/man1/py2pack-%{py_ver}.1.gz

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove py2pack %{_bindir}/py2pack-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE README.rst
%{_bindir}/py2pack
%{_bindir}/py2pack-%{py_ver}
%{_mandir}/man1/py2pack.1.gz
%{_mandir}/man1/py2pack-%{py_ver}.1.gz
%ghost %{_sysconfdir}/alternatives/py2pack
%ghost %{_sysconfdir}/alternatives/py2pack.1.gz
%{_docdir}/%{name}
%{python_sitelib}/py2pack-%{version}-py*.egg-info
%{python_sitelib}/py2pack

%changelog
* Fri Jul 22 2016 tbechtold@suse.com
- Add missing python-six BuildRequires
* Mon Jul  4 2016 tbechtold@suse.com
- Use https for Source url
* Thu Jun 30 2016 tbechtold@suse.com
- update to 0.6.3:
  * Bump version to 0.6.3
  * Set setup.py encoding and retry parsing in error case
  * Move Jinja2 env creation to own function
  * Don't call nosetests when a testsuite was found
  * Fix get_metadata for distutils setup()
  * Also try to get license from classifiers
  * Fix --run deprecation
  * Move requirements related code to requires.py
  * Remove setup.py parsing code
  * Always run setup.py to get metadata
  * Fix README.rst style
* Thu Jun 30 2016 tbechtold@suse.com
- update to 0.6.2:
  * Bump version to 0.6.2
  * Also list tests_require as BuildRequires for openSUSE
  * Reorder Requires/BuildRequires for openSUSE
  * Requirement markers are only available in newer setuptools versions
* Wed Jun 29 2016 tbechtold@suse.com
- update to 0.6.1:
  * Bump version to 0.6.1
  * Improve _canonicalize_setup_data() tests
  * Rerun _canonicalize_setup_data()
  * Remove py33 and py34 from travis and tox
  * travis: Fix python 3 test env variables
  * Don't list "./" in names for extracted zip/tar file
  * Fix minimal version detection for requirements
  * Support requirement markers
  * Fix tests_require handling
  * Adjust some comments
  * Use xmlrpc_client from six
  * Adjust docs for testing
  * Remove whitespaces from README
* Wed Jun 29 2016 tbechtold@suse.com
- update to 0.6.0:
  * Bump version to 0.6.0
  * Add myself as co-maintainer
  * Mention the "--run" as note in README
  * protect against failed eval of setup.py code fragments
  * Also collect tests_require metadata
  * Remove distutils cleanup command
  * Remove pypip.in images from README
  * Use distutils command when running setup.py
  * Add contextmanager to extract a zip/tar into a tempdir
  * Remove bitdeli image from README
  * Relicense under Apache-2.0
  * Move setup.py sandbox run to extra file
  * Also parse entry_points when given as dict
  * Use a "fake" unicode literal from six for decoding
  * Move setup.py parsing to extra file
  * tox: Add possibility to run single test cases
  * Ignore .eggs/ dir in git
  * Update the SPDX mapping file
  * travis: Use matrix to execute tox envs
  * tox: Ignore E402
  * Don't require argparse
  * Remove python 2.6 support
  * travis: remove --use-mirrors pip flag usage
  * tests: ignore console_scripts order during tests
  * Add python 3.4 and 3.5 support
  * Fix company name in spec template
- Update license. It's now Apache-2.0
- Adjust Requires
- USe pypi.io as Source url
* Wed Aug 12 2015 toddrme2178@gmail.com
- Update to version 0.5.0
  + Fix flake8 issues
  + Fix console_script handling
  + Sanitize collected requirements
  + Remove unused 'requires' from opensuse template
  + Quote %%doc filenames if they contain shell metacharacters
  + Add support for "entry_points" and "console_scripts" parameters
  + Support syntactic variations as per the setuptools spec
  + Make "parse" and "run" two separate modes
  + Support same set of setup() parameters in parse and run modes
  + Use setuptools instead of distutils in _run_setup_py() …
  + Run setup.py (instead of just parsing it) to gather more data
  + Adjust Travis CI build
  + Remove commented code and make pep8 happy
  + Remove package create function
  + Fix license detection when license is None
  + Don't include comma in _parse_setup_py regexp
  + fix indentation in README
  + Fix KeyError for license and summary
- Add update-alternatives support for compatibility with
  python 3 version of the package.
* Thu Mar  6 2014 speilicke@suse.com
- Update to version 0.4.10
  + Fix PyPI URL to avoid 301 moved permanently
  + Minor bugfixes
* Mon Feb 10 2014 speilicke@suse.com
- Update to version 0.4.9:
  + Fix coverage report source
  + Add cssselect setup_requires
  + Update SPDX license map
  + Change 'flake8' to 'pep8' target
  + Fix recursive-include for doc
  ...
* Mon Jun 24 2013 speilicke@suse.com
- Update to version 0.4.4:
  + Package scripts (setup.py) as binaries
* Mon Jun 17 2013 speilicke@suse.com
- Only require python-argparse on SLE, it's part of Python-2.7
* Fri May  3 2013 speilicke@suse.com
- Update to version 0.4.3.4:
  + catch more doc files
* Thu May  2 2013 speilicke@suse.com
- Update to version 0.4.3.3:
  + Various bugfixes
* Mon Apr 29 2013 speilicke@suse.com
- Update to version 0.4.3:
  + Generate SPDX-style licenses
  + Find documentation files from local tarball
  + Detect C extensions from local tarball
* Fri Apr 13 2012 saschpe@suse.de
- Update to version 0.4.1.1
  * spec file template conforms to spec-cleaner
* Thu Sep 22 2011 saschpe@suse.de
- Set license to GPL-2.0+ (SPDX style)
- Update to version 0.3.21:
  * Improvements to the Fedora and SUSE spec templates
* Tue Sep 20 2011 saschpe@suse.de
- Buildrequire python-Jinja2 instead of python-jinja2
- Removed %%clean section, use sane default
- Fix non-executable script rpmlint warning
* Thu Jul  7 2011 saschpe@suse.de
- Remove unused %%python_sitearch macro definition
* Wed Jun 22 2011 saschpe@suse.de
- Update to version 0.3.20
  * Use URL for RPM tag 'Source' instead of filename
* Tue May 31 2011 saschpe@suse.de
- Update to version 0.3.18
  * Also list dependencies from 'install_requires'
  * Allow to depend on specific Python versions
* Wed May 18 2011 saschpe@suse.de
- Update to version 0.3.17
  * Fix unicode encoding issues
  * New spec file template for Mageia (formerly Mandriva)
- Changes from version 0.3.16
  * More testing
  * Updated spec file templates according to distro policies
* Wed Apr 27 2011 saschpe@suse.de
- Update to version 0.3.15
  * Minor SUSE template fixes
* Thu Mar 31 2011 saschpe@suse.de
- Update to version 0.3.14
  * Remove #norootforbuild and *.egg-info from %%%%files section
* Wed Mar  9 2011 saschpe@suse.de
- Update to version 0.3.13:
  * Generate manpage and HTML documentation
- Added manpage and HTML documentation
* Wed Feb 16 2011 saschpe@suse.de
- Update to version 0.3.11
  * Remove newer Python features (allow running on older Distros,
    namely RHEL5 and SLES9)
* Wed Jan 26 2011 saschpe@gmx.de
- Update to version 0.3.10
  * Removed SUSE-specific %%files section
  * Added README.rst
* Tue Jan 25 2011 saschpe@suse.de
- Update to version 0.3.9
  * Automatically install egg-info on non-SUSE distros
- Recompressed with bzip2
* Tue Jan 18 2011 saschpe@suse.de
- Update to version 0.3.7
  * Remove authors from description in openSUSE spec template
* Fri Jan 14 2011 saschpe@suse.de
- Update to version 0.3.6
  * Removed double check in openSUSE spec template
  * Added some packager hints
* Thu Jan 13 2011 saschpe@suse.de
- Update to version 0.3.5
  * Better compatibility with older Python releases
  * Version requirement generation for openSUSE spec template
* Wed Jan 12 2011 saschpe@suse.de
- Update to version 0.3.4
  * Use '-q' flag for %%setup in openSUSE spec template
* Mon Dec 20 2010 saschpe@suse.de
- Update to version 0.3.3
  * Moved 'export CFLAGS...' from %%prep to %%build section in
    templates
* Thu Dec 16 2010 saschpe@gmx.de
- Update to version 0.3.2
  * Templates use simple commands instead of macros
* Sun Dec 12 2010 saschpe@gmx.de
- Update to version 0.3.1
  * openSUSE template adds definitions for %%python_sitelib and
    %%python_sitearch for older distros
* Sat Dec 11 2010 saschpe@gmx.de
- Update to version 0.3.0
  * Better error handling
  * Templates generate correct source tarball filenames
* Sat Dec 11 2010 saschpe@gmx.de
- Update to version 0.2.12
  * openSUSE template has SUSE Linux GmbH default copyright
* Sat Dec 11 2010 saschpe@gmx.de
- Update to version 0.2.11
  * Fixed openSUSE spec file template check for non-suse distros
    in %%install section
* Sat Dec 11 2010 saschpe@gmx.de
- Update to version 0.2.10
  * Templates packaged correctly
* Sat Dec 11 2010 saschpe@gmx.de
- Update to version 0.2.8
* Sat Dec 11 2010 saschpe@gmx.de
- Update to version 0.2.7
  * spec file fixes
* Sat Dec 11 2010 saschpe@gmx.de
- Initial version
